@@ -94,7 +94,7 @@ def download(
         filename: str = None,
         suffix_name: str = None,
         headers: dict = None,
-        path: str = "download",
+        path: str = None,
         proxies=None,
         size_limit: int = None,
         range_start: int = None,
@@ -184,6 +184,8 @@ def download(
             os.makedirs(path)
         path_local = os.path.join(path, download_file_name)
 
+    lazypath.make_path(lazypath.file_path(path_local))
+
     if not range_start:
         temp_size = 0  # 已经下载文件大小
     else:
@@ -209,7 +211,10 @@ def download(
         rename_count = 1
         while True:
             download_file_name_rename = f'{download_file_name.split(".")[0]}({rename_count}).{download_file_name.split(".")[1]}'
-            path_local_rename = os.path.join(path, download_file_name_rename)
+            if path:
+                path_local_rename = os.path.join(path, download_file_name_rename)
+            else:
+                path_local_rename = download_file_name_rename
             if os.path.exists(path_local_rename):
                 rename_count += 1
                 continue
